import React, { useState } from "react";

export default function FAQComponent() {
    const [showDescription, setShowDescription] = useState(false);
    const [descriptionIndex, setDescriptionIndex] = useState(null);

    return (
        <div className="faq_style__one z-1 lg:pt-30 pt-24 mt-30 bg-gradient-to-t to-[#FFF1EC] from-white relative">
            <div className="absolute top-[5%] right-[1%] max-w-[9%] z-minus lg:inline-block hidden">
                <img
                    src="/assets/images/illustration/bird-illustration.png"
                    alt="leaf"
                />
            </div>
            <div className="container">
                <div className="text-center lg:pb-[60px] pb-[40px]">
                    <h5 className="section-sub-title-v1">Most wanted Q & A</h5>
                    <h2 className="section-title-v1">
                        Frequently Asked Questions
                    </h2>
                </div>
                <div className="accordion gap-base grid lg:grid-cols-2 grid-cols-1">
                    {[
                        {
                            title: "What are the best locations for wedding tours?",
                            description:
                                "Some of the best wedding tour locations in East Africa include the breathtaking landscapes of Mount Kilimanjaro, the romantic beaches of Zanzibar, and the stunning wildlife reserves of the Serengeti and Maasai Mara.",
                        },
                        {
                            title: "What are some popular tourist destinations in East Africa?",
                            description:
                                "East Africa boasts a diverse range of attractions, including iconic destinations like the Serengeti National Park and Mount Kilimanjaro in Tanzania, the Maasai Mara National Reserve in Kenya, and the Bwindi Impenetrable Forest in Uganda, renowned for its mountain gorilla population.",
                        },
                        {
                            title: "Can we customize our package with you?",
                            description:
                                "Absolutely! We understand that every traveler has unique preferences and requirements. We offer customizable tour packages tailored to your interests, budget, and schedule. Get in touch with our team to create your dream itinerary.",
                        },
                        {
                            title: "What measures are in place to ensure the safety of tourists in East Africa?",
                            description:
                                "Governments and tourism authorities in East Africa prioritize visitor safety through various initiatives. This includes professional guides for wildlife safaris, well-maintained accommodation facilities, and strict conservation regulations. Additionally, many tour operators provide comprehensive travel insurance and adhere to international safety standards.",
                        },
                        {
                            title: "What’s it like to travel with you?",
                            description:
                                "Traveling with us is an adventure like no other! Our experienced guides and staff are dedicated to making your journey safe, comfortable, and unforgettable. Join us on an exploration of East Africa's natural wonders, cultural treasures, and hidden gems.",
                        },
                    ].map((item, index) => (
                        <div className="col-span-1 space-y-base" key={index}>
                            <div className="single__accordion shadow-custom-1 bg-white">
                                <button
                                    type="button"
                                    onClick={() => {
                                        setShowDescription(!showDescription);
                                        setDescriptionIndex(index);
                                    }}
                                    className="toggle px-5 py-5 leading-1.5 text-2md text-start w-full text-dark-1 font-serif"
                                >
                                    {index + 1 < 10
                                        ? "0" + (index + 1)
                                        : index + 1}
                                    . {item.title}
                                </button>
                                {showDescription &&
                                    descriptionIndex === index && (
                                        <div className="hiddenn inner px-5 pb-5">
                                            <p className="text-base font-sans text-dark-3 leading-1.9">
                                                {item.description}
                                            </p>
                                        </div>
                                    )}
                            </div>
                        </div>
                    ))}
                </div>
            </div>
        </div>
    );
}
